ActorSlot

Struct ActorSlot 

pub struct ActorSlot<R: Reactor> {
    pub path: ActorPath,
    pub addr: AddrHash,
    pub mailbox_tx: MailboxSender,
    pub ctrl_tx: UnboundedSender<LifecycleSignal<R>>,
    pub task_handle: Arc<Mutex<Option<Box<dyn SpawnHandle>>>>,
    pub supervisor_addr: Option<AddrHash>,
    pub running: Arc<AtomicBool>,
    pub restart_count: Arc<AtomicU32>,
    pub message_count: Arc<AtomicU64>,
    pub compute_time_ns: Arc<AtomicU64>,
}
A slot in the actor registry.

Fields

path: ActorPathaddr: AddrHashmailbox_tx: MailboxSenderctrl_tx: UnboundedSender<LifecycleSignal<R>>task_handle: Arc<Mutex<Option<Box<dyn SpawnHandle>>>>supervisor_addr: Option<AddrHash>running: Arc<AtomicBool>restart_count: Arc<AtomicU32>

Times this actor path has been restarted by its supervisor.

message_count: Arc<AtomicU64>

Total successful on_message completions. Shared with the actor task so the task can increment without holding the registry lock.

compute_time_ns: Arc<AtomicU64>

Total wall-clock nanoseconds spent in lifecycle hooks.