pub trait SpawnHandle:
SpawnHandle
+ Send
+ Sync
+ 'static { }Expand description
Type-erased handle to a spawned task. Allows aborting a task regardless of which reactor spawned it.
pub trait SpawnHandle:
SpawnHandle
+ Send
+ Sync
+ 'static { }Type-erased handle to a spawned task. Allows aborting a task regardless of which reactor spawned it.