pub enum ActorState {
Running,
Stopped,
}Expand description
Observed lifecycle state of an actor at snapshot time.
Variants
Running
Actor task is running and its mailbox is registered.
Stopped
Actor task has exited (completed, stopped, or crashed).